diff --git a/OpenBis.m b/OpenBis.m
index e37d2164fa144eefb3a8335b36da4951926c5ca0..51f0100451c88ad483f97ba6ef5c19c4c5abfa33 100644
--- a/OpenBis.m
+++ b/OpenBis.m
@@ -520,7 +520,7 @@ classdef OpenBis
             %new_dataset
             % Create a new dataset with files
             % type ... dataset type
             % object ... object for dataset
             % file_list ... list of files (cell string) to upload to new dataset
             % properties ... structure with dataset properties (meta-data)
             % Usage:
@@ -538,7 +538,7 @@ classdef OpenBis
             parse(p, obj, type, object, file_list, varargin{:});
             a = p.Results;
             
-            dataset = obj.pybis.new_dataset(pyargs('type', a.type, 'sample', a.object, ...
+            dataset = obj.pybis.new_dataset(pyargs('type', a.type, 'experiment', a.object, ...
                 'files', a.file_list, 'props', a.properties));
             dataset.save();
             
@@ -520,7 +520,7 @@ classdef OpenBis
             % Create a new dataset with files
             % type ... dataset type
-            % object ... object for dataset
+            % object ... object for dataset (experiment)
             % file_list ... list of files (cell string) to upload to new dataset
             % properties ... structure with dataset properties (meta-data)
diff --git a/openbis_example.mlx b/openbis_example.mlx
index 9e07db03eb030940ba5f3589fd350cd10352e310..2bba055400c5b7f9b72b8dd650f9cc55df5c3b79 100644
Binary files a/openbis_example.mlx and b/openbis_example.mlx differ